@@ -204,7 +204,7 @@ test_that("docsify: footer is still present even if URL is absent", {
     setup_docs("docsify")
     render_docs()
     html <- .readlines("docs/index.html")
-    expect_true(any(grepl("Documentation made with", html)))
+    expect_true(any(grepl("Documentation made with", html, fixed = TRUE)))
 })
 
 for (tool in c("docute", "docsify", "quarto_website")) {
@@ -321,13 +321,43 @@ theme:
     )
 
     render_docs(verbose = .on_ci())
-    expect_true(any(grepl("HELLO THERE", .readlines("docs/index.html"))))
+    expect_true(any(grepl(
+        "HELLO THERE",
+        .readlines("docs/index.html"),
+        fixed = TRUE
+    )))
 
     ### Ensure that the overrides/partial is updated
     cat("HELLO AGAIN", file = "altdoc/overrides/partials/copyright.html")
     render_docs(verbose = .on_ci())
-    expect_false(any(grepl("HELLO THERE", .readlines("docs/index.html"))))
-    expect_true(any(grepl("HELLO AGAIN", .readlines("docs/index.html"))))
+    expect_false(any(grepl(
+        "HELLO THERE",
+        .readlines("docs/index.html"),
+        fixed = TRUE
+    )))
+    expect_true(any(grepl(
+        "HELLO AGAIN",
+        .readlines("docs/index.html"),
+        fixed = TRUE
+    )))
+})
+
+test_that("quarto_website: ensure that README.md is preferred over README.qmd", {
+    skip_on_cran()
+    skip_if(.is_windows() && .on_ci(), "Windows on CI")
+    skip_if(!.quarto_is_installed())
+
+    create_local_package()
+
+    cat("hello there", file = "README.md")
+    cat("---hello there\nhello again", file = "README.qmd")
+    setup_docs("quarto_website")
+    render_docs(verbose = .on_ci())
+    expect_false(any(grepl(
+        "hello again",
+        .readlines("docs/index.html"),
+        fixed = TRUE
+    )))
 })
 
 test_that(".add_pkgdown() works", {
